==> commandir_utils_0.51.tbz: commandir_utils_0.51/libtcp_client.c <==
/* libtcp_client.c
  Functions to connect a client program to libtcp
 */


#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>
#include <stdio.h>
#include <stdlib.h>
#include <strings.h>
#include <string.h>

#include "libtcp_client.h"
#define PORT 65123

	struct sockaddr_in csSA;
	struct hostent *server;
	int cs ;
  unsigned char incomingData[16384];

int networkClientConnect(char * connectToName)
{
  int rc; 
    
	cs = socket( PF_INET , SOCK_STREAM , 0 ) ; // 0 = TCP
	if( cs == -1 ) {
		printf( "Could not create socket\n" ) ;
		exit( -1 ) ;
	}
	bzero( &csSA , sizeof csSA ) ;
	csSA.sin_family = AF_INET ;
	csSA.sin_port = htons( (unsigned short)PORT ) ;
	server = gethostbyname( connectToName );
	
	switch(h_errno) {
	  case HOST_NOT_FOUND:
	  case NO_ADDRESS:
	  case NO_RECOVERY:
	  case TRY_AGAIN:
  	  printf("Unable to find host %s.\n", connectToName);
  	  exit(-1);
  }
	
	memcpy( (char *) &csSA.sin_addr , server->h_addr , server->h_length );

  //Connect to the server
  printf("Connecting to %s...\n", connectToName);
	rc = connect( cs , (void *) &csSA , sizeof csSA ) ;
	if( rc == -1 ) {
		printf( "Could not connect to server.\n" ) ;
		exit( -1 ) ;
	}
	
  return 1;
}

int networkClientRecv(unsigned char * dat, int len)
{
  int rc;
  rc = recv( cs , dat , len , MSG_DONTWAIT );
//  printf("Received data (%d/%d)\n", rc, len);
  return rc;
}

int networkClientSend(unsigned char * bytes, int len)
{
  // buffer for saving data into before putting into file
	int rc ;

	//Send the server the name of the file we would like to request
	rc = send( cs , bytes , len, 0 ) ;
//	printf( "Sent: %d, Request: %d\n" ,rc, len);
  return rc;
}

int networkClientClose()
{
  if(cs != (int)NULL) {
//    printf("Closing cs: %d\n", cs);
  	close(cs);
  }
}

==> commandir_utils_0.61.tbz: commandir_utils_0.61/libtcp_client.c <==
/* libtcp_client.c
  Functions to connect a client program to libtcp
 */


#ifdef WIN
#include <winsock.h>
#define SOCK_NONBLOCK 0
#define MSG_DONTWAIT 0
#define bzero(p, l) memset(p, 0, l)
// #define bcopy(s, t, l) memmove(t, s, l)
#else
#include <sys/socket.h>
#include <arpa/inet.h>
#include <netinet/in.h>
#include <netdb.h>
#define closesocket close
#include <strings.h>
#endif


#include <sys/types.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "libtcp_client.h"
#define PORT 65123

	struct sockaddr_in csSA;
	struct hostent *server;
	int cs ;
  unsigned char incomingData[16384];

int networkClientConnect(char * connectToName)
{
  int rc; 
#ifdef WIN
  WSADATA wsadata;
  WSAStartup(MAKEWORD(1,1), &wsadata);
#endif
    
	cs = socket( PF_INET , SOCK_STREAM , 0 ) ; // 0 = TCP
	if( cs == -1 ) {
		printf( "Could not create socket\n" ) ;
		exit( -1 ) ;
	}
#ifdef WIN
  memset( &csSA, 0, sizeof(csSA) );
#else
	bzero( &csSA , sizeof csSA ) ;
#endif
	csSA.sin_family = AF_INET ;
	csSA.sin_port = htons( (unsigned short)PORT ) ;
	
	server = gethostbyname( connectToName );
	
	switch(h_errno) {
	  case HOST_NOT_FOUND:
	  case NO_ADDRESS:
	  case NO_RECOVERY:
	  case TRY_AGAIN:
  	  printf("Unable to find host %s.\n", connectToName);
  	  exit(-1);
  }
	
	memcpy( (char *) &csSA.sin_addr , server->h_addr , server->h_length );

  //Connect to the server
  printf("Connecting to commandird at %s... ", connectToName);
	rc = connect( cs , (void *) &csSA , sizeof csSA ) ;
	if( rc == -1 ) {
		printf( "Could not connect to server.\n" ) ;
		exit( -1 ) ;
	}
	
	printf("Connected.\n");
  return 1;
}

int networkClientRecv(unsigned char * dat, int len)
{
  int rc;
  rc = recv( cs , dat , len , MSG_DONTWAIT );
//  printf("Received data (%d/%d)\n", rc, len);
  return rc;
}

int networkClientSend(unsigned char * bytes, int len)
{
  // buffer for saving data into before putting into file
	int rc ;

	//Send the server the name of the file we would like to request
	rc = send( cs , bytes , len, 0 ) ;
//	printf( "Sent: %d, Request: %d\n" ,rc, len);
  return rc;
}

void networkClientClose()
{
  if(cs != (int)NULL) {
//    printf("Closing cs: %d\n", cs);
  	closesocket(cs);
  }
}
